==> qastools_1.1.0.orig.tar.xz: qastools-v1.1.0/shared/src/qsnd/ctl_address.hpp <==
/// QasTools: Desktop toolset for the Linux sound system ALSA.
/// \copyright See COPYING file.

#pragma once

#include "qsnd/ctl_address_argument.hpp"
#include <QString>

namespace QSnd
{

/// @brief CTL_Address
///
class CTL_Address
{
  public:
  // -- Construction

  CTL_Address ( const char * ctl_str_n = nullptr );

  CTL_Address ( const QString & ctl_str_n );

  CTL_Address ( const CTL_Address & ctl_addr_n );

  CTL_Address ( CTL_Address && ctl_addr_n );

  ~CTL_Address ();

  // -- Clear

  void
  clear ();

  bool
  is_valid () const
  {
    return !_ctl_name.isEmpty ();
  }

  // -- Address string

  const QString &
  addr_str () const
  {
    return _addr_str;
  }

  /// @brief Sets addr_str() and parses the ctl_name and arguments
  void
  set_addr_str ( const QString & addr_str_n );

  // -- Control name

  const QString &
  ctl_name () const
  {
    return _ctl_name;
  }

  /// @brief Sets the ctl_name() without changing the arguments
  void
  set_ctl_name ( const QString & ctl_name );

  // -- Control arguments

  std::size_t
  num_args () const
  {
    return _args.size ();
  }

  const ::QSnd::CTL_Address_Argument &
  arg ( std::size_t idx_n ) const
  {
    return _args[ idx_n ];
  }

  void
  append_arg ( const ::QSnd::CTL_Address_Argument & arg_n );

  void
  append_arg ( ::QSnd::CTL_Address_Argument && arg_n );

  // -- Comparison

  bool
  match ( const ::QSnd::CTL_Address & ctl_addr_n ) const;

  // -- Assignment operators

  ::QSnd::CTL_Address &
  operator= ( const ::QSnd::CTL_Address & ctl_addr_n );

  ::QSnd::CTL_Address &
  operator= ( ::QSnd::CTL_Address && ctl_addr_n );

  private:
  // -- Utility

  void
  update_addr_str ();

  private:
  // -- Attributes
  QString _addr_str;
  QString _ctl_name;
  std::vector< ::QSnd::CTL_Address_Argument > _args;
};

} // namespace QSnd

==> qastools_1.2.0.orig.tar.xz: qastools-v1.2.0/shared/src/qsnd/ctl_address.hpp <==
/// QasTools: Desktop toolset for the Linux sound system ALSA.
/// \copyright See COPYING file.

#pragma once

#include "qsnd/ctl_address_argument.hpp"
#include <QString>

namespace QSnd
{

/// @brief CTL_Address
///
class CTL_Address
{
  public:
  // -- Construction

  CTL_Address ( const char * ctl_str_n = nullptr );

  CTL_Address ( const QString & ctl_str_n );

  CTL_Address ( const CTL_Address & ctl_addr_n );

  CTL_Address ( CTL_Address && ctl_addr_n );

  ~CTL_Address ();

  // -- Clear

  void
  clear ();

  bool
  is_valid () const
  {
    return !_ctl_name.isEmpty ();
  }

  // -- Address string

  const QString &
  addr_str () const
  {
    return _addr_str;
  }

  /// @brief Sets addr_str() and parses the ctl_name and arguments
  void
  set_addr_str ( const QString & addr_str_n );

  // -- Control name

  const QString &
  ctl_name () const
  {
    return _ctl_name;
  }

  /// @brief Sets the ctl_name() without changing the arguments
  void
  set_ctl_name ( const QString & ctl_name );

  // -- Control arguments

  std::size_t
  num_args () const
  {
    return _args.size ();
  }

  const QSnd::CTL_Address_Argument &
  arg ( std::size_t idx_n ) const
  {
    return _args[ idx_n ];
  }

  void
  append_arg ( const QSnd::CTL_Address_Argument & arg_n );

  void
  append_arg ( QSnd::CTL_Address_Argument && arg_n );

  // -- Comparison

  bool
  match ( const QSnd::CTL_Address & ctl_addr_n ) const;

  // -- Assignment operators

  QSnd::CTL_Address &
  operator= ( const QSnd::CTL_Address & ctl_addr_n );

  QSnd::CTL_Address &
  operator= ( QSnd::CTL_Address && ctl_addr_n );

  private:
  // -- Utility

  void
  update_addr_str ();

  private:
  // -- Attributes
  QString _addr_str;
  QString _ctl_name;
  std::vector< QSnd::CTL_Address_Argument > _args;
};

} // namespace QSnd
